Method: VirtualBox::Net#mac
- Defined in:
- lib/virtual_box/net.rb
#mac ⇒ String (readonly)
The MAC address of the host’s virtual NIC that’s connected to this network.
VirtualBox’s CLI does not provide a way to set the MAC. Therefore, this attribute is read-only, and it is automatically set when the network is registered with VirtualBox.
35 36 37 |
# File 'lib/virtual_box/net.rb', line 35 def mac @mac end |